<?php
/*
Plugin Name: PopShops.com
Plugin URI: http://www.popshops.com/plugins/wordpress
Description: Affiliate tools that everyone can use.  Put products on your site and earn money.  Choose from the largest catalog of affiliate products &mdash; over 20 million!
Author: PopShops.com
Version: 0.5
Author URI: http://www.popshops.com
*/
defined( 'ABSPATH' ) or die( '' );

define( "POPSHOPS_URL", "www.popshops.com" );
define( "POPSHOPS_VERSION", "0.5" );
define( "POPSHOPS_SSL", false );
define( "POPSHOPS_FOLDER", "/wp-content/plugins/popshops");
define( "POPSHOPS_API_KEY", PopShops::find_api_key());
define( "TWO_PLUS", ( ( class_exists( 'WP_Scripts' ) ) ? TRUE : FALSE ) );

$has_php = PopShops::verify_php();

class PopShopsShop {
  var $shop_id = '';
}

class PopShops {

  function install () {
    global $wpdb;
    $table_name = PopShops::table_name();

    if($wpdb->get_var( "SHOW TABLES LIKE '$table_name'")  != $table_name ) {
      add_option( 'popshops_api_key', '', 'PopShops API Key to access ShopBuilder services' );
      add_option( 'popshops_version', POPSHOPS_VERSION, 'PopShops Plugin Version' );

      $sql = "CREATE TABLE ".$table_name." (
      	  id int(11) NOT NULL AUTO_INCREMENT,
      	  shop_id varchar(50) NOT NULL,
      	  sidebar varchar(255),
      	  location varchar(10) NOT NULL default 'page',
      	  randomize tinyint(1) NOT NULL default 0,
      	  page_id int(11),
      	  post_id int(11),
      	  UNIQUE KEY id (id)
      	);";
        $wpdb->query( $sql );
    } else {
      $version = get_option( 'popshops_version' );
      if ( !$version ) {
        add_option( 'popshops_version', POPSHOPS_VERSION, 'PopShops Plugin Version' );
      } else {
        update_option( 'popshops_version', POPSHOPS_VERSION );
      }
    }
  }

  function add_menu_option() {
    if ( function_exists( 'add_options_page' ) ) {
      add_options_page( 'PopShops', 'PopShops', 8, 'popshops/options.php' );
    }
  }

  function save_shop( $shop ) {
    global $wpdb;
    $table_name = PopShops::table_name();
    $shop_id = $shop['shop_id'];
    $location = $wpdb->escape( $shop['location'] );
    $sidebar = ( $location == 'sidebar' ) ? '' : $wpdb->escape( $shop['sidebar'] );
    $page_id = ( $location == 'sidebar' ) ? '' : intval( $shop['page_id'] );
    if ( $shop['id'] && ( $shop['id'] != '' ) ) { $id = $shop['id'];}

    if ( $location != 'page' ) {
      $sidebar = '';
      $page_id = '';
    }

    if ( $id ) {
      $wpdb->query( "UPDATE $table_name
                     SET shop_id = '$shop_id',
                         location = '$location',
                         sidebar = '$sidebar',
                         page_id = '$page_id'
                     WHERE id = $id" );
    } else {
      $wpdb->query( "INSERT INTO $table_name
                    (shop_id,sidebar,location,page_id)
                    VALUES ('$shop_id','$sidebar','$location','$page_id')" );
    }
  }

  function destroy_shop( $shop_id ) {
    if ( $_POST != null ) {
      global $wpdb;
      $shop_id = $shop_id;
      $table_name = PopShops::table_name();
      $shop = $wpdb->get_var( "SELECT * FROM $table_name WHERE id = $shop_id" );
      if ( $shop ) {
        $wpdb->query( "DELETE FROM $table_name WHERE id = $shop_id" );
      }
    }
  }

  function shop_dropdown( $shop_id = '' ) {
    $url = PopShops::url_for( 'plugins/shop_dropdown', "shop_id=" . $shop_id );
		if ( function_exists( 'curl_init' ) ) {
		  $dropdown = curl_init();
		  curl_setopt( $dropdown, CURLOPT_URL, $url);
		  curl_exec( $dropdown );
		  curl_close( $dropdown );
		} else {
		  readfile( $url );
		}
  }

  function footer() {
    PopShops::snippets( 'footer' );
  }

  function sidebar() {
    PopShops::snippets( 'sidebar' );
  }

  function pages( $content = '' ){
    global $wpdb, $post;
    $table_name = PopShops::table_name();
    $shops = $wpdb->get_results( "SELECT * FROM $table_name WHERE page_id = '{$post->ID}'" );
    if ( $shops ) {
      ob_start();
      foreach( $shops as $shop ) {
        PopShops::render_shop($shop);
      }
      $content .= ob_get_clean();
    }
    return $content;
  }

  function posts( $content = '' ) {
    global $post;
    if ( $post->post_type == 'post' ) {
      ob_start();
      $shop = PopShops::find_shop ( "location = 'post' and post_id = ".$post->ID );
      if ( $shop ) {
        PopShops::render_shop($shop);
      }
      $shops = PopShops::find_shops( "location = 'post' and (post_id IS NULL or post_id = '') ORDER BY RAND() limit 1" );
      foreach( $shops as $shop ) {
        PopShops::render_shop($shop);
      }

      $content .= ob_get_clean();
    }
    $content = PopShops::parse_post($content);
    return $content;
  }

  function parse_post ( $content = '' ) {
    // Now parse the post to render any embedded shops
    $open_tag = "[popshops]";
    $close_tag = "[/popshops]";
    $found = true;
    $start = 0;

    while ( $found && ( strlen( $content ) > $start ) ) {
      $start = strpos( $content, $open_tag, $start );
      if ( $start == 0 ) {
        $found = false;
      } else {
        $start += 10;
        $length = strpos( $content, $close_tag, $start ) - $start;
        $shop_key = substr( $content, $start, $length );
        $content = str_replace( $open_tag.$shop_key.$close_tag, PopShops::render_shop_to_string( $shop_key ), $content );
      }
    }
    return $content;
  }

  function render_shop_to_string ( $shop_key ) {
    $shop = new PopShopsShop();
    $shop->shop_id = $shop_key;
    $out = '';
    ob_start();
    PopShops::render_shop( $shop );
    $out .= ob_get_clean();

    return $out;
  }


  function snippets( $location ) {
    $shops = PopShops::find_shops( "location = '$location'" );
    if ( $shops ) {
      foreach ( $shops as $shop ) {
        PopShops::render_shop($shop);
      }
    }
  }

  function render_shop($shop) {
    global $has_php;
    if($has_php == 'false'){
  		echo "<!-- PopShops store code starts here -->
  		<script type=\"text/javascript\" src=\"http://".POPSHOPS_URL
  		."/shops/".$shop->shop_id."\"></script>
  		<!-- PopShops store code ends here -->";
  	}
  	elseif($has_php == 'true'){
  		# Determine the current base URL
  		if(!isset($_SERVER['REQUEST_URI'])) {
  		   $psps_base_url = $_SERVER['PHP_SELF'];
  		   if (isset($HTTP_SERVER_VARS['QUERY_STRING'])) { $psps_base_url .= $HTTP_SERVER_VARS['QUERY_STRING']; }
  		} else {
  		   $psps_base_url = $_SERVER['REQUEST_URI'];
  		}

  		$psps_parameters = '';

      foreach ($_REQUEST as $key => $value) {
        if (strpos($key,"psps_") > -1 ) {
          $psps_parameters .= '&'.$key.'='.urlencode($value);
          $psps_base_url = str_replace('&'.$key.'='.urlencode($value), "", $psps_base_url);
          $psps_base_url = str_replace($key.'='.urlencode($value), "", $psps_base_url);
        }
      }

  		$psps_parameters .= "&psps_show_search=true";
      $psps_parameters .= "&psps_show_navigation=true";
      $psps_parameters .= "&psps_show_products=true";

      $psps_url = "?psps_base_url=".urlencode($psps_base_url);

  		$psps_url="http://".POPSHOPS_URL."/shops/php/".$shop->shop_id."$psps_url$psps_parameters";

  		# Include the shop
  		if (function_exists('curl_init')) {
  		  $shop=curl_init();
  		  curl_setopt($shop,CURLOPT_URL,$psps_url);
  		  curl_exec($shop);
  		  curl_close($shop);
  		} else {
  		  readfile($psps_url);
  		}
  	}
  }

  function find_api_key() {
    return get_option( 'popshops_api_key' );
  }

  function save_api_key($key) {
    update_option( 'popshops_api_key', $key );
  }

  function find_shops( $conditions = '1' ) {
    global $wpdb;
    $table_name = PopShops::table_name();
    $shops = $wpdb->get_results( "SELECT * FROM $table_name WHERE $conditions" );
    return $shops;
  }

  function find_shops_with_names() {
    $shops = PopShops::find_shops();
    if (sizeof($shops) == 0) {
      return $shops;
    } else {
      return PopShops::find_shop_names($shops);
    }
  }

  function find_shop_names($shops=array()) {
    $params = array();
    foreach ( $shops as $shop ) {
     array_push ( $params, $shop->shop_id );
    }
    $params = implode( ",", $params );

    $names = PopShops::send("plugins/shop_names", "&keys=[".$params."]");
    $names = explode(",",$names);
    $count = 0;
    foreach( $names as $name ) {
      $shops[$count]->shop_name = $names[$count];
      $count += 1;
    }
    return $shops;
  }

  function find_shop( $shop_id ) {
	  global $wpdb;
	  $table_name = PopShops::table_name();
	  return $wpdb->get_row( "SELECT * FROM $table_name WHERE id = $shop_id" );
  }

  function find_shop_id( $shop_id ) {
		$shop = PopShops::find_shop( $shop_id );
		$shop_id = $shop->id;
		return $shop_id;
  }

  function find_all_pages() {
    global $wpdb;
    return $wpdb->get_results( "SELECT * FROM $wpdb->posts WHERE post_type = 'page'" );
  }

  function find_page( $page_id ) {
    global $wpdb;
    return $wpdb->get_row( "SELECT * FROM $wpdb->posts WHERE post_type = 'page' and id = $page_id" );
  }

  function find_post( $post_id ) {
    global $wpdb;
    return $wpdb->get_row( "SELECT * FROM $wpdb->posts WHERE post_type = 'post' and id = $post_id" );
  }

  function verify_php(){
    return PopShops::send("plugins/verify_php");
  }

  function table_name() {
    global $wpdb;
    return $wpdb->prefix."popshops";
  }

  function h( $string ) {
    return htmlentities( $string, ENT_QUOTES, 'UTF-8' );
  }

  function url_for($path='',$params='') {
    $protocol = (POPSHOPS_SSL == true) ? 'https://' : 'http://';
    $params = ($params == '') ? '' : '&' . $params;
    return $protocol . POPSHOPS_URL . '/' . $path . '?key=' . get_option('popshops_api_key') . '&plugin_type=wordpress&version=' . POPSHOPS_VERSION . $params;
  }

  function image($name,$alt) {
    return '<img src="http://' . POPSHOPS_URL . '/images/' . $name . '" alt="' . $alt .'" />';
  }

  function activate_key() {
    $key = PopShops::send('plugins/activate_key','user[email]=' . $_REQUEST['user_email'] .'&user[password]=' . $_REQUEST['user_password']);
    if ( $key != 'false' ) {
      PopShops::save_api_key($key);
    }
    return $key;
  }

  function send( $url, $params = '' ){
    $url = PopShops::url_for( $url, $params );

  	if( function_exists( 'curl_init' ) ){
  		$ch = curl_init( $url );

  		curl_setopt( $ch, CURLOPT_HEADER, 0 );
  		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
  		curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, 0 );

  		$response = curl_exec( $ch );

  		if ( curl_errno( $ch ) ) {
  	    trigger_error( curl_error( $ch ), E_USER_WARNING );
  			return( 0 );
  		} else {
  	    curl_close( $ch );
  		}
  	}
  	else{
  		$response = file_get_contents( $_url );
  	}
  	return $response;
  }

  function render_page_shop_form(){
    PopShops::render_post_shop_form("page");
  }

  function render_post_shop_form($type=""){
    if (POPSHOPS_API_KEY) {
    	global $wpdb, $post;
      $table_name = PopShops::table_name();
      $type = $type == "" ? 'post' : 'page';
      $shop = $wpdb->get_row( "SELECT * FROM $table_name WHERE ".$type."_id = '{$post->ID}'" );
      $shop_id = '';
      if ( $shop ) {
        $shop_id = $shop->shop_id;
      }
      PopShops::render_shop_form($shop_id);
    }
  }

  function render_shop_form($shop_id) {
    ?>
  		<fieldset id="postpopshopdiv" class="dbx-box">
  		<h3 class="dbx-handle">PopShops</h3>
  		<div class="dbx-content">
  			<span id="option-list">
  			  <?php echo PopShops::shop_dropdown($shop_id); ?>
  			</span>
  			<div>
  			Shop will be added at the bottom of the post.<br/>
  			<a href="http://<?php echo POPSHOPS_URL ?>/manage_shops/" target="_new">Create a new shop</a><br />
  			<a href="#" onclick="PopShopsBrowser.refresh_dropdown();return false;">Refresh shop list above</a>
  			</div>
  		</div>
  		</fieldset>
  	<?php
  }

  function update_post($post_id){
    global $wpdb;
    if ( POPSHOPS_API_KEY && $_REQUEST['popshops_shop']['shop_id'] != '') {
      $table_name = PopShops::table_name();
      $shop_id = $_REQUEST['popshops_shop']['shop_id'];
      $post = $wpdb->get_row( "SELECT * FROM wp_posts WHERE id = '{$post_id}'" );
      $type = ($post->post_type == 'post') ? 'post' : 'page';
      $shop = $wpdb->get_row( "SELECT * FROM $table_name WHERE ".$type."_id = '{$post_id}'" );

      if ( $shop ) {
        $wpdb->query( "UPDATE $table_name
                       SET shop_id = '$shop_id',
                           location = '".$type."',
                           sidebar = '',
                           ".$type."_id = '$post_id'
                       WHERE id = $shop->id" );
      } else {
        $wpdb->query( "INSERT INTO $table_name
                      (shop_id,sidebar,location,".$type."_id)
                      VALUES ('$shop_id','','".$type."','$post_id')" );
      }
    }
  }

  function browser() {
    if ( POPSHOPS_API_KEY ) {
      if ( !current_user_can('edit_posts') && !current_user_can('edit_pages') ) return;
      if (!(strstr($_SERVER['PHP_SELF'], 'post-new.php') || strstr($_SERVER['PHP_SELF'], 'page-new.php')
  			|| strstr($_SERVER['PHP_SELF'], 'post.php') || strstr($_SERVER['PHP_SELF'], 'page.php'))) return;
      ?>
      <link rel="stylesheet" href="http://<?php echo POPSHOPS_URL ?>/stylesheets/plugins/shopbuilder_widget.css" type="text/css" />
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/javascripts/prototype.js"></script>
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/javascripts/scriptaculous.js"></script>
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/javascripts/effects.js"></script>
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/javascripts/dragdrop.js"></script>
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/javascripts/accordion<?php echo ((PopShops::version() >= 2.5) ? '2' : '')?>.js"></script>
      <script type="text/javascript" src="http://<?php echo POPSHOPS_URL ?>/plugins/shopbuilder?key=<?php echo POPSHOPS_API_KEY ?>&plugin_type=wordpress&version=<?php echo POPSHOPS_VERSION ?>"></script>
      <?php
    }
  }

  function version() {
    global $wp_db_version;
  	$version = 2.0;

  	if ( $wp_db_version > 6124 )
  		$version = 2.5;
  	elseif ( class_exists('WP_Scripts') )
  		$version = 2.1;

  	return $version;
  }

  # Thanks to http://wordpress.org/extend/plugins/vipers-video-quicktags/ for how to integrate
  # buttons into the new TinyMCE
  function add_buttons() {
    if ( POPSHOPS_API_KEY && PopShops::version() > 2.0 && 'true' == get_user_option('rich_editing') ) {

     	// WordPress 2.5+ (TinyMCE 3.x)
			if ( PopShops::version() >= 2.5 ) {
				add_filter( 'mce_external_plugins', array('PopShops', 'mce_external_plugins') );
				add_filter( 'mce_buttons', array('PopShops', 'mce_buttons') );
			}

			// WordPress 2.1+ (TinyMCE 2.x)
			else {
				add_filter('mce_plugins', array('PopShops', 'mce_plugins'));
       	add_filter('mce_buttons', array('PopShops', 'mce_buttons'));
       	add_action('tinymce_before_init', array('PopShops', 'tinymce_before_init'));
			}
    }
  }

	function mce_external_plugins( $plugins ) {
		// WordPress 2.5
		$plugins['popshops'] = get_bloginfo('wpurl') . POPSHOPS_FOLDER . '/resources/tinymce3/editor_plugin.js';
		return $plugins;
	}
	function mce_plugins($plugins) {
		// WordPress 2.1
		array_push($plugins, 'popshops');
		return $plugins;
	}
	function mce_buttons($buttons) {
		if ( PopShops::version() < 2.5 ) {
			array_push( $buttons, 'separator' );
			array_push( $buttons, 'popshops' );
		} else {
			array_push( $buttons, 'popshops' );
		}
		return $buttons;
	}
	function tinymce_before_init() {
		// WordPress 2.1
		echo 'tinyMCE.loadPlugin("popshops", "' . get_bloginfo('wpurl') . POPSHOPS_FOLDER . '/resources/tinymce2/");';
	}

}

register_activation_hook( 'popshops/popshops.php', array( 'PopShops','install' ) );
add_action( 'admin_menu', array( 'PopShops', 'add_menu_option' ) );
add_action( 'wp_footer', array( 'PopShops', 'footer' ) );
add_action( 'wp_meta', array( 'PopShops', 'sidebar' ) );
add_action( 'dbx_post_sidebar', array( 'Popshops', 'render_post_shop_form' ) );
add_action( 'dbx_page_sidebar', array( 'PopShops', 'render_page_shop_form' ) );
add_action( 'save_post', array( 'PopShops', 'update_post' ) );
add_action( 'init', array( 'PopShops', 'add_buttons' ) );
add_action( 'admin_head', array( 'PopShops', 'browser' ) );
add_filter( 'the_content', array( 'PopShops', 'posts' ) );
add_filter( 'the_content', array( 'PopShops', 'pages' ) );

?>